@@ -22,15 +22,15 @@
 #include <QCommandLineParser>
 #include <QDateTime>
 #include <QDebug>
-#include <QDesktopWidget>
 #include <QFile>
-#include <QFont>
 #include <QLibraryInfo>
 #include <QLocale>
 #include <QLoggingCategory>
 #include <QMessageBox>
+#include <QScreen>
 #include <QString>
 #include <QStringList>
+#include <QSettings>
 #include <QTranslator>
 #include <QLockFile>
 
@@ -87,10 +87,7 @@ int main(int argc, char *argv[])
         {{"p", "pretend"}, QObject::tr("Test mode for GUI, you can advance to different screens without actially installing.")},
         {{"r", "reboot"}, QObject::tr("Reboots automatically when done installing.")},
         {{"s", "sync"}, QObject::tr("Installing with rsync instead of cp on custom partitioning.\n"
-            "-- doesn't format /root and it doesn't work with encryption.")},
-        {"media-check", QObject::tr("Always check the installation media at the beginning.")},
-        {"no-media-check", QObject::tr("Do not check the installation media at the beginning.\n"
-            "Not recommended unless the installation media is guaranteed to be free from errors.")}});
+            "-- doesn't format /root and it doesn't work with encryption.")}});
     parser.addPositionalArgument("config-file", QObject::tr("Load a configuration file as specified by <config-file>."), "<config-file>");
     parser.process(a);
 
@@ -145,7 +142,7 @@ int main(int argc, char *argv[])
     qDebug() << "Installer version:" << VERSION;
     try {
         MInstall minstall(appConf, parser, cfgfile);
-        const QRect &geo = a.desktop()->availableGeometry(&minstall);
+        const QRect &geo = a.primaryScreen()->availableGeometry();
         if (parser.isSet("oobe")) minstall.setGeometry(geo);
         else minstall.move((geo.width() - minstall.width()) / 2, (geo.height() - minstall.height()) / 2);
         minstall.show();
