@@ -1,8 +1,7 @@
 /***************************************************************************
  * Out-of-Box Experience - GUI and related functions of the installer.
- ***************************************************************************
  *
- *   Copyright (C) 2022 by AK-47, along with transplanted code:
+ *   Copyright (C) 2022-2023 by AK-47, along with transplanted code:
  *    - Copyright (C) 2003-2010 by Warren Woodford
  *    - Heavily edited, with permision, by anticapitalista for antiX 2011-2014.
  *    - Heavily revised by dolphin oracle, adrian, and anticaptialista 2018.
@@ -20,12 +19,15 @@
  *
  * This file is part of the gazelle-installer.
  ***************************************************************************/
+
 #include <sys/stat.h>
 #include <QDebug>
 #include <QMessageBox>
 #include <QFileInfo>
 #include <QLocale>
 #include <QTimeZone>
+#include "mprocess.h"
+#include "msettings.h"
 #include "oobe.h"
 
 Oobe::Oobe(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent, const QSettings &appConf, bool oem, bool modeOOBE)
